@@ -7,7 +7,7 @@ class ImpersonateMiddleware(object):
         if request.user.is_authenticated() and \
            '_impersonate' in request.session:
             new_user = request.session['_impersonate']
-            if check_allow_for_user(request.user, new_user) and \
+            if check_allow_for_user(request, new_user) and \
                check_allow_for_uri(request.path):
                 request.user = new_user
                 request.user.is_impersonate = True
